@@ -17,13 +17,19 @@ AVAILABLE_PYTHON_VERSIONS = (
     "python38",
     "python37",
 )
-YANDEX_S3_URL = 'https://storage.yandexcloud.net'
+YANDEX_S3_URL = "https://storage.yandexcloud.net"
 YANDEX_FUNCTIONS_URL = "https://functions.yandexcloud.net"
 YANDEX_CLIENT_ID = "9878e3bd8f1e4bc292ee9c74bbc736a2"
-YANDEX_OAUTH_URL = furl("https://oauth.yandex.ru/authorize").add({
-    "response_type": "token",
-    "client_id": YANDEX_CLIENT_ID,
-}).url
+YANDEX_OAUTH_URL = (
+    furl("https://oauth.yandex.ru/authorize")
+    .add(
+        {
+            "response_type": "token",
+            "client_id": YANDEX_CLIENT_ID,
+        }
+    )
+    .url
+)
 HANDLERS = {
     "wsgi": "handlers.wsgi.handle",
     "django": "handlers.wsgi.handle",
@@ -32,3 +38,4 @@ HANDLERS = {
     "raw": None,
 }
 MAX_DIRECT_ARCHIVE_SIZE = 4170000
+ENV_YC_OAUTH = "YC_OAUTH"
